@@ -4,8 +4,8 @@ import (
 	"fmt"
 	"os"
 
-	"github.com/armosec/kubescape/core/cautils"
-	"github.com/armosec/kubescape/core/cautils/getter"
+	"github.com/armosec/kubescape/v2/core/cautils"
+	"github.com/armosec/kubescape/v2/core/cautils/getter"
 )
 
 const NO_SUBMIT_QUERY = "utm_source=GitHub&utm_medium=CLI&utm_campaign=no_submit"
@@ -32,19 +32,20 @@ func (reportMock *ReportMock) SetClusterName(clusterName string) {
 }
 
 func (reportMock *ReportMock) GetURL() string {
-	return getter.GetArmoAPIConnector().GetFrontendURL()
-}
-
-func (reportMock *ReportMock) DisplayReportURL() {
-	u := fmt.Sprintf("https://%s/account/login", getter.GetArmoAPIConnector().GetFrontendURL())
+	u := fmt.Sprintf("https://%s/account/sign-up", getter.GetArmoAPIConnector().GetFrontendURL())
 	if reportMock.query != "" {
 		u += fmt.Sprintf("?%s", reportMock.query)
 	}
+	return u
+}
+
+func (reportMock *ReportMock) DisplayReportURL() {
+
 	sep := "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
 	message := sep + "\n"
 	message += "Scan results have not been submitted: " + reportMock.message + "\n"
 	message += "Sign up for free: "
-	message += u + "\n"
+	message += reportMock.GetURL() + "\n"
 	message += sep + "\n"
 	cautils.InfoTextDisplay(os.Stderr, fmt.Sprintf("\n%s\n", message))
 }
